<?php
/**
 * Free PrestaShop MailMunch integration
 *
 * @category  Prestashop
 * @category  Module
 * @author    Mediacom87 <support@mediacom87.net>
 * @copyright Mediacom87
 * @license   commercial license see in the module
 * @version   1.1.0
 */

if (!defined('_PS_VERSION_')) {

    exit;

}

include_once dirname(__FILE__) . '/class/mediacom87.php';

/**
 * med_zopimv2 class.
 *
 * @extends Module
 */
class MedMailMunchFree extends MedMailMunchFreeBis
{
    /**
     * __construct function.
     *
     * @access public
     * @return void
     */
    public function __construct()
    {
        $this->name = 'medmailmunchfree';
        $this->tab = 'advertising_marketing';
        $this->version = '1.1.0';
        $this->author = 'Mediacom87';
        $this->need_instance = 0;
        $this->module_key = '';
        $this->addons_id = ''; // xxxx

        parent::__construct();

        $this->displayName = $this->l('Free MailMunch integration module on PrestaShop');
        $this->description = $this->l('Use this module to help you to integrate MailMunch on PrestaShop.');

        $this->confirmUninstall = $this->l(' If you uninstall this add-on you will lose all of its configuration. Are you sure you want to uninstall it?');

        if (version_compare(_PS_VERSION_, '1.6.0.0', '>=')) {

            $this->bootstrap = true;

        } else {

            $this->bootstrap = false;

        }

        $this->conf = unserialize(Configuration::get($this->name));
        $this->tpl_path = _PS_ROOT_DIR_ . '/modules/' . $this->name;

    }

    /**
     * install function.
     *
     * @access public
     * @return void
     */
    public function install()
    {
        if (!parent::install() || !$this->defaultConf() || !$this->registerHook('displayHeader')) {

            return false;

        }

        return true;
    }

    /**
     * uninstall function.
     *
     * @access public
     * @return void
     */
    public function uninstall()
    {
        if (!parent::uninstall() || !Configuration::deleteByName($this->name)) {
            return false;
        }

        return true;
    }

    /**
     * defaultConf function.
     *
     * @access public
     * @return void
     */
    public function defaultConf()
    {
        $conf = array();

        $conf['script'] = '';

        if (!Configuration::updateValue($this->name, serialize($conf))) {

            return false;

        }

        return true;
    }

    /**
     * getContent function.
     *
     * @access public
     * @return void
     */
    public function getContent($tab = 'AdminModules')
    {
        $this->errors = array();
        $output = '';

        $languages = Language::getLanguages();

        $form_url = AdminController::$currentIndex . '&amp;configure=' . $this->name . '&amp;token=' . Tools::getAdminToken($tab . (int) Tab::getIdFromClassName($tab) . (int) $this->context->cookie->id_employee);

        if (Tools::isSubmit('saveconf')) {

            $this->postProcess();

            if (!count($this->errors)) {

                $output .= $this->displayConfirmation($this->l('Settings updated'));

            }

        }

        if (isset($this->addons_id) && $this->addons_id) {

            $json_modules = $this->medJsonModuleFile();

        } else {

            $json_modules = null;
        }

        $this->context->smarty->assign(array(
                'form_url' => $form_url,
                'addons_id' => $this->addons_id,
                'tpl_path' => $this->tpl_path,
                'path' => $this->_path,
                'languages' => $languages,
                'description' => $this->description,
                'author' => $this->author,
                'name' => $this->name,
                'version' => $this->version,
                'ps_version' => _PS_VERSION_,
                'iso_code' => $this->isoCode(),
                'iso_domain' => $this->isoCode(true),
                'id_active_lang' => $this->context->language->id,
                'json_modules' => $json_modules,
                'config' => $this->conf
            ));

        if (count($this->errors)) {

            $output .= $this->displayError(implode('<br />', $this->errors));

        }

        $output .= $this->display(__FILE__, 'views/templates/admin/admin.tpl');

        $this->context->controller->addJS($this->_path.'libraries/js/riotcompiler.min.js');

        $this->context->controller->addCSS($this->_path.'views/css/admin/admin.css');

        $output .= $this->display(__FILE__, 'libraries/prestui/ps-tags.tpl');

        return $output;

    }

    /**
     * postProcess function.
     *
     * @access private
     * @return void
     */
    private function postProcess()
    {
        $this->conf['script'] = Tools::getValue('script');

        if (Configuration::updateValue($this->name, serialize($this->conf))) {

            return true;

        } else {

            $this->errors[] = $this->l('Error during saving settings');
            return false;

        }
    }

    public function hookDisplayHeader()
    {
        if (!Tools::isEmpty($this->conf['script'])) {

            $this->context->smarty->assign('config', $this->conf);
            return $this->display(__FILE__, 'displayHeader.tpl');
        }
    }
}
